@@ -1,31 +1,42 @@
 #!/usr/bin/python
-import os,socket,time,re,BeautifulSoup,optparse, urllib2, base64, json
+"""
 ###############################################################
-# Digital Loggers Web Power Switch management
-###############################################################
-# Description: This is both a module and a script
-#              
-#              The module provides a python class named
-#              powerswitch that allows managing the web power
-#              switch from python programs.
-# 
-#              When run as a script this acts as a command
-#              line utilty to manage the DLI Power switch.
-# Author: Dwight Hubbard d@dhub.me
-# Copyright: This module may be used for any use personal
-#            or commercial as long as the author and copyright
-#            notice are included in full.
+Digital Loggers Web Power Switch management
 ###############################################################
+ Description: This is both a module and a script
+
+              The module provides a python class named
+              powerswitch that allows managing the web power
+              switch from python programs.
+
+              When run as a script this acts as a command
+              line utility to manage the DLI Power switch.
+ Author: Dwight Hubbard d@dhub.me
+ Copyright: This module may be used for any use personal
+            or commercial as long as the author and copyright
+            notice are included in full.
+"""
+
+# Python built in modules
+import os
+import sys
+import time
+import optparse
+import base64
+import json
+import urllib2
+
+# External modules
+import BeautifulSoup
 
 # Global settings
-# Timeout in seconds
 TIMEOUT=5
 CYCLETIME=1.5
 CONFIG_DEFAULTS={'timeout':TIMEOUT,'cycletime':CYCLETIME,'userid':'admin','password':'4321','hostname':'192.168.0.100'}
 CONFIG_FILE=os.path.expanduser('~/.dlipower.conf')
 
 class powerswitch:
-    """ Manage the DLI Web power switch """
+    """ Powerswitch class to manage the Digital Loggers Web power switch """
     def __init__(self,userid=None,password=None,hostname=None,timeout=None):
         CONFIG=self.load_configuration()
         if userid:
@@ -71,7 +82,7 @@ class powerswitch:
         fh=open(CONFIG_FILE,'w')
         # Make sure the file perms are correct before we write data
         # that can include the password into it.
-        os.fchmod(fh.fileno(),0600)
+        os.fchmod(fh.fileno(),0o0600)
         if fh:
             json.dump(CONFIG,fh,sort_keys=True, indent=4)
             fh.close()
@@ -88,20 +99,26 @@ class powerswitch:
         request.add_header("Authorization", "Basic %s" % base64string)   
         try:
             result = urllib2.urlopen(request,timeout=self.timeout).read()
-        except urllib2.URLError,timeout:
+        except urllib2.URLError:
+            return None
+        except timeout:
             return None
         return result
     def off(self,outlet=0):
         """ Turn off a power to an outlet """
         self.geturl(url= 'outlet?%d=OFF' % outlet)
+        return self.status(outlet) != 'OFF'
     def on(self,outlet=0):
         """ Turn on power to an outlet """
         self.geturl(url= 'outlet?%d=ON' % outlet)
+        return self.status(outlet) != 'ON'
     def cycle(self,outlet=0):
         """ Cycle power to an outlet """
+        start_status=self.status(outlet)
         self.off(outlet)
         time.sleep(CYCLETIME)
         self.on(outlet)
+        return self.status(outlet) != start_status
     def statuslist(self):
         """ Return the status of all outlets in a list, 
         each item will contain 3 items plugnumber, hostname and state  """
@@ -110,25 +127,29 @@ class powerswitch:
         if not url:
             return None
         soup=BeautifulSoup.BeautifulSoup(url)
+        # Get the root of the table containing the port status info
         try:
-            powertable=soup.findAll('table')[5]
+            root=soup.findAll('td',text='1')[0].parent.parent.parent
         except IndexError:
             return None
-        for temp in powertable.findAll('tr')[2:]:
+        for temp in root.findAll('tr'):
             columns=temp.findAll('td')
-            plugnumber=columns[0].string
-            hostname=columns[1].string
-            state=columns[2].find('font').string
-            outlets.append([int(plugnumber),hostname,state])
+            #print len(columns)
+            if len(columns) == 5:
+                plugnumber=columns[0].string
+                hostname=columns[1].string
+                state=columns[2].find('font').string
+                outlets.append([int(plugnumber),hostname,state])
         return outlets
     def printstatus(self):
         """ Print the status off all the outlets as a table to stdout """
         if not self.statuslist():
-            print "Unable to communicte to the Web power switch at %s" % self.hostname
+            print("Unable to communicate to the Web power switch at %s" % self.hostname)
             return None
-        print 'Outlet\t%-15.15s\tState' % 'Hostname'
+        print('Outlet\t%-15.15s\tState' % 'Hostname')
         for item in self.statuslist():
-            print '%d\t%-15.15s\t%s' % (item[0],item[1],item[2])
+            print('%d\t%-15.15s\t%s' % (item[0],item[1],item[2]))
+        return
     def status(self,outlet=1):
         """ Return the status of an outlet, returned value will be one of: On, Off, Unknown """
         outlets=self.statuslist()
@@ -154,12 +175,12 @@ if __name__ == "__main__":
     if len(args):
         if len(args) == 2:
             if args[0].lower() in ['on','poweron']:
-                switch.on(int(args[1]))
+                sys.exit(switch.on(int(args[1])))
             if args[0].lower() in ['off','poweroff']:
-                switch.off(int(args[1]))
+                sys.exit(switch.off(int(args[1])))
             if args[0].lower() in ['cycle']:
-                switch.cycle(int(args[1]))
+                sys.exit(switch.cycle(int(args[1])))
             if args[0].lower() in ['status']:
-                print switch.status(int(args[1]))
+                print(switch.status(int(args[1])))
     else:
         switch.printstatus()
